==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/forms/lang/lt.js <==
/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'forms', 'lt', {
	button: {
		title: 'Mygtuko savybės',
		text: 'Tekstas (Reikšmė)',
		type: 'Tipas',
		typeBtn: 'Mygtukas',
		typeSbm: 'Siųsti',
		typeRst: 'Išvalyti'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Žymimojo langelio savybės',
		radioTitle: 'Žymimosios akutės savybės',
		value: 'Reikšmė',
		selected: 'Pažymėtas',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Formos savybės',
		menu: 'Formos savybės',
		action: 'Veiksmas',
		method: 'Metodas',
		encoding: 'Kodavimas'
	},
	hidden: {
		title: 'Nerodomo lauko savybės',
		name: 'Vardas',
		value: 'Reikšmė'
	},
	select: {
		title: 'Atrankos lauko savybės',
		selectInfo: 'Informacija',
		opAvail: 'Galimos parinktys',
		value: 'Reikšmė',
		size: 'Dydis',
		lines: 'eilučių',
		chkMulti: 'Leisti daugeriopą atranką',
		required: 'Required', // MISSING
		opText: 'Tekstas',
		opValue: 'Reikšmė',
		btnAdd: 'Įtraukti',
		btnModify: 'Modifikuoti',
		btnUp: 'Aukštyn',
		btnDown: 'Žemyn',
		btnSetValue: 'Laikyti pažymėta reikšme',
		btnDelete: 'Trinti'
	},
	textarea: {
		title: 'Teksto srities savybės',
		cols: 'Ilgis',
		rows: 'Plotis'
	},
	textfield: {
		title: 'Teksto lauko savybės',
		name: 'Vardas',
		value: 'Reikšmė',
		charWidth: 'Ilgis simboliais',
		maxChars: 'Maksimalus simbolių skaičius',
		required: 'Required', // MISSING
		type: 'Tipas',
		typeText: 'Tekstas',
		typePass: 'Slaptažodis',
		typeEmail: 'El. paštas',
		typeSearch: 'Paieška',
		typeTel: 'Telefono numeris',
		typeUrl: 'Nuoroda'
	}
} );

==> ckeditor_4.12.1+dfsg.orig.tar.xz: ckeditor-dev-4.12.1/plugins/forms/lang/lt.js <==
/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'forms', 'lt', {
	button: {
		title: 'Mygtuko savybės',
		text: 'Tekstas (Reikšmė)',
		type: 'Tipas',
		typeBtn: 'Mygtukas',
		typeSbm: 'Siųsti',
		typeRst: 'Išvalyti'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Žymimojo langelio savybės',
		radioTitle: 'Žymimosios akutės savybės',
		value: 'Reikšmė',
		selected: 'Pažymėtas',
		required: 'Privalomas'
	},
	form: {
		title: 'Formos savybės',
		menu: 'Formos savybės',
		action: 'Veiksmas',
		method: 'Metodas',
		encoding: 'Kodavimas'
	},
	hidden: {
		title: 'Nerodomo lauko savybės',
		name: 'Vardas',
		value: 'Reikšmė'
	},
	select: {
		title: 'Atrankos lauko savybės',
		selectInfo: 'Informacija',
		opAvail: 'Galimos parinktys',
		value: 'Reikšmė',
		size: 'Dydis',
		lines: 'eilučių',
		chkMulti: 'Leisti daugeriopą atranką',
		required: 'Privalomas',
		opText: 'Tekstas',
		opValue: 'Reikšmė',
		btnAdd: 'Įtraukti',
		btnModify: 'Modifikuoti',
		btnUp: 'Aukštyn',
		btnDown: 'Žemyn',
		btnSetValue: 'Laikyti pažymėta reikšme',
		btnDelete: 'Trinti'
	},
	textarea: {
		title: 'Teksto srities savybės',
		cols: 'Ilgis',
		rows: 'Plotis'
	},
	textfield: {
		title: 'Teksto lauko savybės',
		name: 'Vardas',
		value: 'Reikšmė',
		charWidth: 'Ilgis simboliais',
		maxChars: 'Maksimalus simbolių skaičius',
		required: 'Privalomas',
		type: 'Tipas',
		typeText: 'Tekstas',
		typePass: 'Slaptažodis',
		typeEmail: 'El. paštas',
		typeSearch: 'Paieška',
		typeTel: 'Telefono numeris',
		typeUrl: 'Nuoroda'
	}
} );
